$title

# Delete versions ${old_version + 1} to $new_version of $page.name Delete version $new_version of $page.name Delete $page.name

Are you sure you want to delete versions ${old_version + 1} to $new_version of this page? Are you sure you want to delete version $new_version of this page? Are you sure you want to completely delete this page?
This is the only version the page, so the page will be removed completely! This is an irreversible operation.